@@ -4,8 +4,8 @@
 
 ;; Author: Thomas Fini Hansen <xen@xen.dk>
 ;; Created: August 11, 2019
-;; Package-Version: 20260117.43
-;; Package-Revision: 8acd7788b4ab
+;; Package-Version: 20260206.2340
+;; Package-Revision: 71c0fcb54a13
 ;; Package-Requires: ((emacs "26.2"))
 ;; Keywords: tools
 ;; URL: https://github.com/xendk/reaper
@@ -254,9 +254,7 @@ Used to relocate point to the same entry after redisplaying.")
   (interactive)
   (reaper--check-credentials)
   (reaper-with-buffer
-   ;; TODO: figure out arguments to reuse window not just in current
-   ;; frame but across all frames. And use NORECORD for good measure.
-   (pop-to-buffer (current-buffer))))
+   (pop-to-buffer (current-buffer) '(display-buffer-reuse-window (reusable-frames . visible)) t)))
 
 (defun reaper-get-running-timer-note ()
   "Return the note (description) of the current running timer.
@@ -353,11 +351,9 @@ Prompt for a project and task, and insert the id of the selected task."
 
 (defun reaper-ensure-project-tasks ()
   "Ensure that we have project and tasks fetched."
-  ;; TODO: Should use reaper-with-buffer, unless we're sure all
-  ;; callers already did (which we're not as long as start-new-timer
-  ;; calls us.)
-  (unless (bound-and-true-p reaper-project-tasks)
-    (reaper-refresh-project-tasks)))
+  (reaper-with-buffer
+   (unless (bound-and-true-p reaper-project-tasks)
+     (reaper-refresh-project-tasks))))
 
 (defun reaper-refresh-project-tasks ()
   "Fetch projects and tasks from Harvest."
@@ -648,10 +644,7 @@ BUFFER is the buffer to insert response into, URL is the URL fetched.
 
 Returns the decoded JSON data."
   (when (fboundp 'url-http--insert-file-helper)
-    ;; XXX: This is HTTP/S specific and should be moved to url-http
-    ;; instead.  See bug#17549.
     (url-http--insert-file-helper buffer url))
-  ;; TODO: check url-http-response-status
   (url-insert-buffer-contents buffer url)
   (goto-char (point-min))
   ;; Ensure JSON false values is nil.
